@@ -4,9 +4,9 @@
  * An example program for CERBERUS.
  * ( http://sourceforge.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
- * Copyright (C) 2005-2006  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.0 2005/11/11
+ * Version: 1.6.8   2009/05/28
  */
 #include <stdio.h>
 #include <string.h>
@@ -14,12 +14,14 @@
 #include <stdlib.h>
 #include <time.h>
 
-int main(int argc, char *argv[]) {
+int main(int argc, char *argv[])
+{
 	static char seed[40];
 	int i;
 	srand(time(NULL) / 30);
 	memset(seed, 0, sizeof(seed));
-	for (i = 0; i < sizeof(seed) - 1; i++) seed[i] = (rand() % 64) + 33;
+	for (i = 0; i < sizeof(seed) - 1; i++)
+		seed[i] = (rand() % 64) + 33;
 	printf("%s\n", seed);
 	return 0;
 }
