@@ -3,14 +3,15 @@
  *
  * Testing program for fs/tomoyo_capability.c
  *
- * Copyright (C) 2005-2008  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.0   2008/04/01
+ * Version: 1.6.8   2009/05/28
  *
  */
 #include "include.h"
 
-static int child(void *arg) {
+static int child(void *arg)
+{
 	errno = 0;
 	pivot_root("/proc", proc_policy_dir);
 	return errno;
@@ -20,7 +21,8 @@ static int domain_fd = EOF;
 static const char *capability = "";
 static char self_domain[4096] = "";
 
-static int write_policy(void) {
+static int write_policy(void)
+{
 	FILE *fp = fopen(proc_policy_domain_policy, "r");
 	char buffer[8192];
 	char *cp;
@@ -32,15 +34,19 @@ static int write_policy(void) {
 	write(domain_fd, capability, strlen(capability));
 	write(domain_fd, "\n", 1);
 	if (!fp) {
-		printf("allow_capability %s : BUG: capability read failed\n", capability);
+		printf("allow_capability %s : BUG: capability read failed\n",
+		       capability);
 		return 0;
 	}
 	while (fgets(buffer, sizeof(buffer) - 1, fp)) {
 		cp = strchr(buffer, '\n');
-		if (cp) *cp = '\0';
-		if (!strncmp(buffer, "<kernel>", 8)) domain_found = !strcmp(self_domain, buffer);
+		if (cp)
+			*cp = '\0';
+		if (!strncmp(buffer, "<kernel>", 8))
+			domain_found = !strcmp(self_domain, buffer);
 		if (domain_found) {
-			if (!strncmp(buffer, "allow_capability ", 17) && !strcmp(buffer + 17, capability)) {
+			if (!strncmp(buffer, "allow_capability ", 17) &&
+			    !strcmp(buffer + 17, capability)) {
 				policy_found = 1;
 				break;
 			}
@@ -48,14 +54,16 @@ static int write_policy(void) {
 	}
 	fclose(fp);
 	if (!policy_found) {
-		printf("allow_capability %s : BUG: capability write failed\n", capability);
+		printf("allow_capability %s : BUG: capability write failed\n",
+		       capability);
 		return 0;
 	}
 	errno = 0;
 	return 1;
 }
 
-static void delete_policy(void) {
+static void delete_policy(void)
+{
 	const char *cp = "allow_capability ";
 	write(domain_fd, "delete ", 7);
 	write(domain_fd, cp, strlen(cp));
@@ -63,53 +71,66 @@ static void delete_policy(void) {
 	write(domain_fd, "\n", 1);
 }
 
-static void show_result(int result, char should_success) {
+static void show_result(int result, char should_success)
+{
 	printf("allow_capability %s : ", capability);
 	if (should_success) {
-		if (result != EOF) printf("OK\n");
-		else printf("FAILED: %s\n", strerror(errno));
+		if (result != EOF)
+			printf("OK\n");
+		else
+			printf("FAILED: %s\n", strerror(errno));
 	} else {
 		if (result == EOF) {
-			if (errno == EPERM) printf("OK: Permission denied.\n");
-			else printf("FAILED: %s\n", strerror(errno));
+			if (errno == EPERM)
+				printf("OK: Permission denied.\n");
+			else
+				printf("FAILED: %s\n", strerror(errno));
 		} else {
 			printf("BUG\n");
 		}
 	}
 }
 
-static void SetCapability(void) {
+static void set_capability(void)
+{
 	static char buffer[1024];
 	memset(buffer, 0, sizeof(buffer));
-	snprintf(buffer, sizeof(buffer) - 1, "MAC_FOR_CAPABILITY::%s=enforcing\n", capability);
-	WriteStatus(buffer);
+	snprintf(buffer, sizeof(buffer) - 1,
+		 "MAC_FOR_CAPABILITY::%s=enforcing\n", capability);
+	write_status(buffer);
 }
 
-static void UnsetCapability(void) {
+static void unset_capability(void)
+{
 	static char buffer[1024];
 	memset(buffer, 0, sizeof(buffer));
-	snprintf(buffer, sizeof(buffer) - 1, "MAC_FOR_CAPABILITY::%s=disabled\n", capability);
-	WriteStatus(buffer);
+	snprintf(buffer, sizeof(buffer) - 1,
+		 "MAC_FOR_CAPABILITY::%s=disabled\n", capability);
+	write_status(buffer);
 }
 
-static void StageCapabilityTest(void) {
-	char tmp1[128], tmp2[128];
+static void stage_capability_test(void)
+{
+	char tmp1[128];
+	char tmp2[128];
 	memset(tmp1, 0, sizeof(tmp1));
 	memset(tmp2, 0, sizeof(tmp2));
 
 	capability = "inet_tcp_create";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int fd = socket(AF_INET, SOCK_STREAM, 0);
 		show_result(fd, 1);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 		delete_policy();
 		fd = socket(AF_INET, SOCK_STREAM, 0);
 		show_result(fd, 0);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	{
 		int fd1 = socket(AF_INET, SOCK_STREAM, 0);
 		int fd2 = socket(AF_INET, SOCK_STREAM, 0);
@@ -126,98 +147,114 @@ static void StageCapabilityTest(void) {
 		bind(fd3, (struct sockaddr *) &addr, sizeof(addr));
 		bind(fd4, (struct sockaddr *) &addr, sizeof(addr));
 		getsockname(fd1, (struct sockaddr *) &addr, &size);
-		
+
 		capability = "inet_tcp_listen";
-		SetCapability();
+		set_capability();
 		if (write_policy()) {
 			show_result(listen(fd1, 5), 1);
 			delete_policy();
 			show_result(listen(fd2, 5), 0);
 		}
-		UnsetCapability();
-		
-		capability = "inet_tcp_connect";
-		SetCapability();
-		if (write_policy()) {
-			show_result(connect(fd3, (struct sockaddr *) &addr, sizeof(addr)), 1);
-			delete_policy();
-			show_result(connect(fd4, (struct sockaddr *) &addr, sizeof(addr)), 0);
-		}
-		UnsetCapability();
+		unset_capability();
 
-		if (fd1 != EOF) close(fd1);
-		if (fd2 != EOF) close(fd2);
-		if (fd3 != EOF) close(fd3);
-		if (fd4 != EOF) close(fd4);
+		capability = "inet_tcp_connect";
+		set_capability();
+		if (write_policy()) {
+			show_result(connect(fd3, (struct sockaddr *) &addr,
+					    sizeof(addr)), 1);
+			delete_policy();
+			show_result(connect(fd4, (struct sockaddr *) &addr,
+					    sizeof(addr)), 0);
+		}
+		unset_capability();
+
+		if (fd1 != EOF)
+			close(fd1);
+		if (fd2 != EOF)
+			close(fd2);
+		if (fd3 != EOF)
+			close(fd3);
+		if (fd4 != EOF)
+			close(fd4);
 	}
 
 	capability = "use_inet_udp";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int fd = socket(AF_INET, SOCK_DGRAM, 0);
 		show_result(fd, 1);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 		delete_policy();
 		fd = socket(AF_INET, SOCK_DGRAM, 0);
 		show_result(fd, 0);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "use_inet_ip";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int fd = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP);
 		show_result(fd, 1);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 		delete_policy();
 		fd = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP);
 		show_result(fd, 0);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "use_route";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int fd = socket(AF_ROUTE, SOCK_RAW, 0);
 		show_result(fd, 1);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 		delete_policy();
 		fd = socket(AF_ROUTE, SOCK_RAW, 0);
 		show_result(fd, 0);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "use_packet";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int fd = socket(AF_PACKET, SOCK_RAW, 0);
 		show_result(fd, 1);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 		delete_policy();
 		fd = socket(AF_PACKET, SOCK_RAW, 0);
 		show_result(fd, 0);
-		if (fd != EOF) close(fd);
+		if (fd != EOF)
+			close(fd);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "use_kernel_module";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
-		if (!is_kernel26) show_result((int) create_module("", 0), 1);
+		if (!is_kernel26)
+			show_result((int) create_module("", 0), 1);
 		show_result(init_module("", NULL), 1);
 		show_result(delete_module(""), 1);
 		delete_policy();
-		if (!is_kernel26) show_result((int) create_module("", 0), 0);
+		if (!is_kernel26)
+			show_result((int) create_module("", 0), 0);
 		show_result(init_module("", NULL), 0);
 		show_result(delete_module(""), 0);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "create_fifo";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/XXXXXX");
 		close(mkstemp(tmp1));
@@ -228,10 +265,10 @@ static void StageCapabilityTest(void) {
 		show_result(mknod(tmp1, S_IFIFO, 0), 0);
 		unlink(tmp1);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "create_block_dev";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/XXXXXX");
 		close(mkstemp(tmp1));
@@ -242,10 +279,10 @@ static void StageCapabilityTest(void) {
 		show_result(mknod(tmp1, S_IFBLK, MKDEV(1, 0)), 0);
 		unlink(tmp1);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "create_char_dev";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/XXXXXX");
 		close(mkstemp(tmp1));
@@ -254,12 +291,12 @@ static void StageCapabilityTest(void) {
 		unlink(tmp1);
 		delete_policy();
 		show_result(mknod(tmp1, S_IFCHR, MKDEV(1, 3)), 0);
-		unlink(tmp1);		
+		unlink(tmp1);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "create_unix_socket";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/XXXXXX");
 		close(mkstemp(tmp1));
@@ -278,108 +315,128 @@ static void StageCapabilityTest(void) {
 		addr.sun_family = AF_UNIX;
 		strcpy(tmp1, "/tmp/XXXXXX");
 		strncpy(addr.sun_path, tmp1, sizeof(addr.sun_path) - 1);
-		show_result(bind(fd1, (struct sockaddr *) &addr, sizeof(addr)), 1);
+		show_result(bind(fd1, (struct sockaddr *) &addr, sizeof(addr)),
+			    1);
 		unlink(tmp1);
 		delete_policy();
-		show_result(bind(fd2, (struct sockaddr *) &addr, sizeof(addr)), 0);
+		show_result(bind(fd2, (struct sockaddr *) &addr, sizeof(addr)),
+			    0);
 		unlink(tmp1);
-		if (fd1 != EOF) close(fd1);
-		if (fd2 != EOF) close(fd2);
+		if (fd1 != EOF)
+			close(fd1);
+		if (fd2 != EOF)
+			close(fd2);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "SYS_MOUNT";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
-		show_result(mount("/", "/", "nonexistent", 0, NULL), 1);
+		show_result(mount("/", "/", "tmpfs", 0, NULL), 1);
 		delete_policy();
-		show_result(mount("/", "/", "nonexistent", 0, NULL), 0);
+		show_result(mount("/", "/", "tmpfs", 0, NULL), 0);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_UMOUNT";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
-		show_result(umount("/"), 1);
-		if (access("/", W_OK)) mount("", "/", "", MS_REMOUNT, NULL);
+		mount("/tmp", "/tmp", "tmpfs", 0, NULL);
+		show_result(umount("/tmp"), 1);
 		delete_policy();
+		mount("/tmp", "/tmp", "tmpfs", 0, NULL);
 		show_result(umount("/"), 0);
-		if (access("/", W_OK)) mount("", "/", "", MS_REMOUNT, NULL);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_REBOOT";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
-		show_result(reboot(LINUX_REBOOT_MAGIC1, LINUX_REBOOT_MAGIC2,
-				   0x0000C0DE /* Use invalid value so that the system won't reboot. */, NULL), 1);
-		delete_policy();
-		show_result(reboot(LINUX_REBOOT_MAGIC1, LINUX_REBOOT_MAGIC2,
-				   0x0000C0DE /* Use invalid value so that the system won't reboot. */, NULL), 0);
+		FILE *fp = fopen("/proc/sys/kernel/ctrl-alt-del", "a+");
+		unsigned int c;
+		if (fp && fscanf(fp, "%u", &c) == 1) {
+			show_result(reboot(LINUX_REBOOT_CMD_CAD_ON), 1);
+			delete_policy();
+			show_result(reboot(LINUX_REBOOT_CMD_CAD_ON), 0);
+			fprintf(fp, "%u\n", c);
+		} else {
+			/* Use invalid value */
+			show_result(reboot(0x0000C0DE), 1);
+			delete_policy();
+			show_result(reboot(0x0000C0DE), 0);
+		}
+		if (fp)
+			fclose(fp);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_CHROOT";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		show_result(chroot("/"), 1);
 		delete_policy();
 		show_result(chroot("/"), 0);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "SYS_PIVOT_ROOT";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int error;
 		char *stack = malloc(8192);
 		pid_t pid = clone(child, stack + (8192 / 2), CLONE_NEWNS, NULL);
-		while (waitpid(pid, &error, __WALL) == EOF && errno == EINTR);
+		while (waitpid(pid, &error, __WALL) == EOF && errno == EINTR)
+			error += 0; /* Dummy. */
 		errno = WIFEXITED(error) ? WEXITSTATUS(error) : -1;
 		show_result(errno ? EOF : 0, 1);
 		delete_policy();
 		pid = clone(child, stack + (8192 / 2), CLONE_NEWNS, NULL);
-		while (waitpid(pid, &error, __WALL) == EOF && errno == EINTR);
+		while (waitpid(pid, &error, __WALL) == EOF && errno == EINTR)
+			error += 0; /* Dummy. */
 		errno = WIFEXITED(error) ? WEXITSTATUS(error) : -1;
 		show_result(errno ? EOF : 0, 0);
 		free(stack);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	signal(SIGINT, SIG_IGN);
 	capability = "SYS_KILL";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		show_result(kill(pid, SIGINT), 1);
 		show_result(tkill(gettid(), SIGINT), 1);
 #ifdef __NR_tgkill
-		if (is_kernel26) show_result(tgkill(pid, gettid(), SIGINT), 1);
+		if (is_kernel26)
+			show_result(tgkill(pid, gettid(), SIGINT), 1);
 #endif
 		delete_policy();
 		show_result(kill(pid, SIGINT), 0);
 		show_result(tkill(gettid(), SIGINT), 0);
 #ifdef __NR_tgkill
-		if (is_kernel26) show_result(tgkill(pid, gettid(), SIGINT), 0);
+		if (is_kernel26)
+			show_result(tgkill(pid, gettid(), SIGINT), 0);
 #endif
 	}
-	UnsetCapability();
+	unset_capability();
 	signal(SIGINT, SIG_DFL);
 
 	capability = "SYS_KEXEC_LOAD";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 #ifdef __NR_sys_kexec_load
-		if (is_kernel26) show_result(sys_kexec_load(0, 0, NULL, 0), 1);
+		if (is_kernel26)
+			show_result(sys_kexec_load(0, 0, NULL, 0), 1);
 #endif
 		delete_policy();
 #ifdef __NR_sys_kexec_load
-		if (is_kernel26) show_result(sys_kexec_load(0, 0, NULL, 0), 0);
+		if (is_kernel26)
+			show_result(sys_kexec_load(0, 0, NULL, 0), 0);
 #endif
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_VHANGUP";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int pty_fd = EOF, status = 0;
 		int pipe_fd[2] = { EOF, EOF };
@@ -428,10 +485,10 @@ static void StageCapabilityTest(void) {
 			show_result(status ? EOF : 0, 0);
 		}
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "SYS_TIME";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		struct timeval tv;
 		struct timezone tz;
@@ -441,7 +498,8 @@ static void StageCapabilityTest(void) {
 		gettimeofday(&tv, &tz);
 		show_result(settimeofday(&tv, &tz), 1);
 		memset(&buf, 0, sizeof(buf));
-		buf.modes = 0x100; /* Use invalid value so that the clock won't change. */
+		buf.modes = 0x100; /* Use invalid value so that the clock
+				      won't change. */
 		show_result(adjtimex(&buf), 1);
 		delete_policy();
 		now = time(NULL);
@@ -449,24 +507,27 @@ static void StageCapabilityTest(void) {
 		gettimeofday(&tv, &tz);
 		show_result(settimeofday(&tv, &tz), 0);
 		memset(&buf, 0, sizeof(buf));
-		buf.modes = 0x100; /* Use invalid value so that the clock won't change. */
+		buf.modes = 0x100; /* Use invalid value so that the clock
+				      won't change. */
 		show_result(adjtimex(&buf), 0);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_NICE";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		show_result(nice(0), 1);
-		show_result(setpriority(PRIO_PROCESS, pid, getpriority(PRIO_PROCESS, pid)), 1);
+		show_result(setpriority(PRIO_PROCESS, pid,
+					getpriority(PRIO_PROCESS, pid)), 1);
 		delete_policy();
 		show_result(nice(0), 0);
-		show_result(setpriority(PRIO_PROCESS, pid, getpriority(PRIO_PROCESS, pid)), 0);
+		show_result(setpriority(PRIO_PROCESS, pid,
+					getpriority(PRIO_PROCESS, pid)), 0);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "SYS_SETHOSTNAME";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		char buffer[4096];
 		memset(buffer, 0, sizeof(buffer));
@@ -480,10 +541,10 @@ static void StageCapabilityTest(void) {
 		getdomainname(buffer, sizeof(buffer) - 1);
 		show_result(setdomainname(buffer, strlen(buffer)), 0);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_LINK";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/link_source_XXXXXX");
 		close(mkstemp(tmp1));
@@ -499,10 +560,10 @@ static void StageCapabilityTest(void) {
 		unlink(tmp2);
 		unlink(tmp1);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_SYMLINK";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/symlink_target_XXXXXX");
 		close(mkstemp(tmp1));
@@ -518,10 +579,10 @@ static void StageCapabilityTest(void) {
 		unlink(tmp2);
 		unlink(tmp1);
 	}
-	UnsetCapability();
-	
+	unset_capability();
+
 	capability = "SYS_RENAME";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/rename_old_XXXXXX");
 		close(mkstemp(tmp1));
@@ -537,10 +598,10 @@ static void StageCapabilityTest(void) {
 		unlink(tmp2);
 		unlink(tmp1);
 	}
-	UnsetCapability();
+	unset_capability();
 
 	capability = "SYS_UNLINK";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		strcpy(tmp1, "/tmp/unlinkXXXXXX");
 		close(mkstemp(tmp1));
@@ -550,42 +611,54 @@ static void StageCapabilityTest(void) {
 		close(mkstemp(tmp1));
 		show_result(unlink(tmp1), 0);
 	}
-	UnsetCapability();
+	unset_capability();
 	unlink(tmp1);
-	
+
 	capability = "SYS_CHMOD";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		show_result(chmod("/dev/null", 0222), 1);
 		delete_policy();
 		show_result(chmod("/dev/null", 0444), 0);
 	}
-	UnsetCapability();
+	unset_capability();
 	chmod("/dev/null", 0666);
-	
+
 	capability = "SYS_CHOWN";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		show_result(chown("/dev/null", 1, 1), 1);
 		delete_policy();
 		show_result(chown("/dev/null", 2, 2), 0);
 	}
-	UnsetCapability();
+	unset_capability();
 	chown("/dev/null", 0, 0);
 
 	capability = "SYS_IOCTL";
-	SetCapability();
-	if (write_policy()) {
+	set_capability();
+	if (0 && write_policy()) {
 		int fd = open("/dev/null", O_RDONLY);
-		show_result(ioctl(fd, 0 /* Use invalid value so that nothing happen. */), 1);
+		show_result(ioctl(fd, 0 /* Use invalid value so that nothing
+					   happen. */), 1);
 		delete_policy();
-		show_result(ioctl(fd, 0 /* Use invalid value so that nothing happen. */), 0);
+		show_result(ioctl(fd, 0 /* Use invalid value so that nothing
+					   happen. */), 0);
 		close(fd);
 	}
-	UnsetCapability();
+	if (write_policy()) {
+		struct ifreq ifreq;
+		int fd = socket(PF_INET, SOCK_DGRAM, IPPROTO_IP);
+		memset(&ifreq, 0, sizeof(ifreq));
+		snprintf(ifreq.ifr_name, sizeof(ifreq.ifr_name) - 1, "lo");
+		show_result(ioctl(fd, 35123, &ifreq), 1);
+		delete_policy();
+		show_result(ioctl(fd, 35123, &ifreq), 0);
+		close(fd);
+	}
+	unset_capability();
 
 	capability = "SYS_PTRACE";
-	SetCapability();
+	set_capability();
 	if (write_policy()) {
 		int status = 0;
 		int pipe_fd[2] = { EOF, EOF };
@@ -630,12 +703,18 @@ static void StageCapabilityTest(void) {
 			show_result(status ? EOF : 0, 0);
 		}
 	}
-	UnsetCapability();
+	unset_capability();
 }
 
-int main(int argc, char *argv[]) {
-	Init();
+int main(int argc, char *argv[])
+{
+	ccs_test_init();
 	domain_fd = open(proc_policy_domain_policy, O_WRONLY);
+	if (domain_fd == EOF && errno == ENOENT) {
+		fprintf(stderr, "You can't use this program for this kernel."
+			"\n");
+		return 1;
+	}
 	{
 		int self_fd = open(proc_policy_self_domain, O_RDONLY);
 		memset(self_domain, 0, sizeof(self_domain));
@@ -644,8 +723,8 @@ int main(int argc, char *argv[]) {
 		write(domain_fd, self_domain, strlen(self_domain));
 		write(domain_fd, "\n", 1);
 	}
-	StageCapabilityTest();
+	stage_capability_test();
 	close(domain_fd);
-	ClearStatus();
+	clear_status();
 	return 0;
 }
